@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.4   2015/05/05
+ * Version: 1.8.5   2015/11/11
  */
 
 #ifndef _SECURITY_CCSECURITY_INTERNAL_H
@@ -884,23 +884,8 @@ enum ccs_value_type {
  */
 #define CCS_RETRY_REQUEST 1
 
-/* Ignore gfp flags which are not supported. */
-#ifndef __GFP_HIGHIO
-#define __GFP_HIGHIO 0
-#endif
-#ifndef __GFP_NOWARN
-#define __GFP_NOWARN 0
-#endif
-#ifndef __GFP_NORETRY
-#define __GFP_NORETRY 0
-#endif
-#ifndef __GFP_NOMEMALLOC
-#define __GFP_NOMEMALLOC 0
-#endif
-
 /* The gfp flags used by TOMOYO. */
-#define CCS_GFP_FLAGS (__GFP_WAIT | __GFP_IO | __GFP_HIGHIO | __GFP_NOWARN | \
-		       __GFP_NORETRY | __GFP_NOMEMALLOC)
+#define CCS_GFP_FLAGS GFP_NOFS
 
 /* Size of read buffer for /proc/ccs/ interface. */
 #define CCS_MAX_IO_READ_QUEUE 64
